@@ -15,7 +15,7 @@ class AriaService:
     def __init__(self, base_url, session_id, **kwargs):
         self._base_url = base_url
         self._token = None
-        self._delta_token = None
+        self.delta_token = None
         self._paging_token = None
         self._session_id = session_id
         self._timeout_default = 30 if 'timeout' not in kwargs else int(kwargs['timeout'])
@@ -52,17 +52,19 @@ class AriaService:
         res.raise_for_status()
         return self._process_aria_message(res.json(), 'token')
 
-    def get_messages(self):
+    def get_messages(self, delta_token=None):
+        if delta_token is not None:
+            self.delta_token = delta_token
         res = requests.get(
             self._base_url+'/message',
             headers=self._headers,
             timeout=self._timeout_default,
-            params={'deltaToken': self._delta_token, 'isSubscription': True}
+            params={'deltaToken': self.delta_token, 'isSubscription': True}
         )
         res.raise_for_status()
         data = res.json()
         if 'deltaToken' in data:
-            self._delta_token = data.get('deltaToken')
+            self.delta_token = data.get('deltaToken')
         return self._process_aria_message(data)
 
     def search_messages(self, data, timeout=None, limit=1000):
@@ -95,7 +97,7 @@ class AriaService:
                      'content-type': mimetypes.guess_type(filename)}
                 )
         if 'on_behalf' in kwargs and kwargs['on_behalf'] is not None:
-            message['on_behalf'] = kwargs['on_behalf']
+            message['onBehalf'] = kwargs['on_behalf']
         return requests.post('{}/message'.format(self._base_url), json=message, headers=self._headers)
 
     def delete_message(self, id):
