@@ -51,17 +51,6 @@ class AriaBot:
             self.read_token_file.write_text('')
             logging.warning('read_token_file not set in config, creating new file {0}'.format(self.read_token_file.name))
 
-    @staticmethod
-    def parse_environment(environment, config):
-        if 'environments' not in config:
-            raise AriaBotException("Missing environment configuration")
-
-        for env in config['environments']:
-            if env['name'] == environment:
-                return env
-
-        raise AriaBotException("Missing configuration for environment {}".format(environment))
-
     def _populate_commands(self):
         if 'commands' not in self.config:
             logging.warning("No commands configured")
@@ -71,6 +60,8 @@ class AriaBot:
                 if 'flags' in _cmd:
                     flags = eval(_cmd['flags'])
                 _cmd['pattern'] = re.compile(_cmd['pattern'], flags)
+                # push the full config to all commands
+                _cmd['config'] = self.config
                 _module = None
                 try:
                     if 'module' in _cmd:
@@ -265,6 +256,7 @@ class AriaBotCommand:
         self.bot = kwargs['bot']
         self.pattern = kwargs['pattern']
         self.name = kwargs['name']
+        self.config = kwargs['config']
         AriaBotCommand._commands.append(self)
 
     @staticmethod
